# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class PixelFormat(Enum):
    YUV410P = "YUV410P"
    YUV411P = "YUV411P"
    YUV420P = "YUV420P"
    YUV422P = "YUV422P"
    YUV440P = "YUV440P"
    YUV444P = "YUV444P"
    YUVJ411P = "YUVJ411P"
    YUVJ420P = "YUVJ420P"
    YUVJ422P = "YUVJ422P"
    YUVJ440P = "YUVJ440P"
    YUVJ444P = "YUVJ444P"
    YUV420P10LE = "YUV420P10LE"
    YUV422P10LE = "YUV422P10LE"
    YUV440P10LE = "YUV440P10LE"
    YUV444P10LE = "YUV444P10LE"
    YUV420P12LE = "YUV420P12LE"
    YUV422P12LE = "YUV422P12LE"
    YUV440P12LE = "YUV440P12LE"
    YUV444P12LE = "YUV444P12LE"
    YUV420P10BE = "YUV420P10BE"
    YUV422P10BE = "YUV422P10BE"
    YUV440P10BE = "YUV440P10BE"
    YUV444P10BE = "YUV444P10BE"
    YUV420P12BE = "YUV420P12BE"
    YUV422P12BE = "YUV422P12BE"
    YUV440P12BE = "YUV440P12BE"
    YUV444P12BE = "YUV444P12BE"
